@@ -1,27 +1,24 @@
-#' Reporting \code{htest} objects (Correlation, t-test...)
+#' Reporting `htest` objects (Correlation, t-test...)
 #'
-#' Create reports for \code{htest} objects (\code{t.test()}, \code{cor.test()},
+#' Create reports for `htest` objects (`t.test()`, `cor.test()`,
 #' etc.).
 #'
-#' @param x Object of class \code{htest}.
-#' @param table Provide the output of  \code{report_table()} to avoid its
+#' @param x Object of class `htest`.
+#' @param table Provide the output of  `report_table()` to avoid its
 #'   re-computation.
-#' @param effectsize Provide the output of \code{report_effectsize()} to avoid
+#' @param effectsize Provide the output of `report_effectsize()` to avoid
 #'   its re-computation.
 #' @inheritParams report
 #'
 #' @inherit report return seealso
 #'
 #' @examples
-#' report(cor.test(iris$Sepal.Width, iris$Sepal.Length, method = "spearman"))
-#' report(cor.test(iris$Sepal.Width, iris$Sepal.Length, method = "pearson"))
 #' report(t.test(iris$Sepal.Width, iris$Sepal.Length))
 #' report(t.test(iris$Sepal.Width, iris$Sepal.Length, var.equal = TRUE))
 #' report(t.test(mtcars$mpg ~ mtcars$vs))
 #' report(t.test(mtcars$mpg, mtcars$vs, paired = TRUE))
 #' report(t.test(iris$Sepal.Width, mu = 1))
-#' @importFrom insight format_ci
-#' @return An object of class \code{\link{report}}.
+#' @return An object of class [report()].
 #' @export
 report.htest <- function(x, ...) {
   table <- report_table(x, ...)
@@ -34,9 +31,6 @@ report.htest <- function(x, ...) {
 # report_effectsize -------------------------------------------------------
 
 #' @rdname report.htest
-#' @importFrom effectsize effectsize interpret_r interpret_d
-#' @importFrom parameters model_parameters
-#' @importFrom insight model_info
 #' @export
 report_effectsize.htest <- function(x, ...) {
   table <- effectsize::effectsize(x, verbose = FALSE, ...)
@@ -68,10 +62,39 @@ report_effectsize.htest <- function(x, ...) {
     )
 
     table <- table[c(estimate, paste0(estimate, c("_CI_low", "_CI_high")))]
+  }
 
-    # For correlations ---------------
-  } else if (insight::model_info(x)$is_correlation) {
+  # For wilcox test ---------------
 
+  if (insight::model_info(x)$is_ranktest && !insight::model_info(x)$is_correlation) {
+    # same as Pearson's r
+    interpretation <- effectsize::interpret_r(table[[estimate]], ...)
+    rules <- .text_effectsize(attributes(interpretation)$rule_name)
+
+    if (estimate %in% c("r_rank_biserial")) {
+      main <- paste0("r (rank biserial) = ", insight::format_value(table[[estimate]]))
+    } else {
+      main <- paste0(estimate, " = ", insight::format_value(table[[estimate]]))
+    }
+
+    statistics <- paste0(
+      main,
+      ", ",
+      insight::format_ci(table$CI_low, table$CI_high, ci)
+    )
+
+    table <- data_rename(
+      as.data.frame(table),
+      c("CI_low", "CI_high"),
+      paste0(estimate, c("_CI_low", "_CI_high"))
+    )
+
+    table <- table[c(estimate, paste0(estimate, c("_CI_low", "_CI_high")))]
+  }
+
+  # For correlations ---------------
+
+  if (insight::model_info(x)$is_correlation) {
     # Pearson
     interpretation <- effectsize::interpret_r(table[[estimate]], ...)
     rules <- .text_effectsize(attributes(interpretation)$rule_name)
@@ -91,16 +114,20 @@ report_effectsize.htest <- function(x, ...) {
       statistics <- main
       table <- table[c(estimate)]
     }
+  }
 
-    # TODO: Chi-squared test -------------
-  } else {
+  # TODO: Chi-squared test -------------
+
+  if (insight::model_info(x)$is_chi2test || insight::model_info(x)$is_proptest ||
+    insight::model_info(x)$is_xtab) {
     stop("This test is not yet supported. Please open an issue: https://github.com/easystats/report/issues")
   }
 
   parameters <- paste0(interpretation, " (", statistics, ")")
 
   # Return output
-  as.report_effectsize(parameters,
+  as.report_effectsize(
+    parameters,
     summary = parameters,
     table = table,
     interpretation = interpretation,
@@ -112,13 +139,10 @@ report_effectsize.htest <- function(x, ...) {
 }
 
 
-
 # report_table ------------------------------------------------------------
 
 
 #' @rdname report.htest
-#' @importFrom parameters model_parameters
-#' @importFrom insight model_info
 #' @export
 report_table.htest <- function(x, ...) {
   table_full <- parameters::model_parameters(x, ...)
@@ -127,9 +151,16 @@ report_table.htest <- function(x, ...) {
   # If t-test, effect size
   if (insight::model_info(x)$is_ttest) {
     table_full <- cbind(table_full, attributes(effsize)$table)
+    table <- data_remove(
+      table_full,
+      c("Parameter", "Group", "Mean_Group1", "Mean_Group2", "Method")
+    )
   }
 
-  table <- data_remove(table_full, c("Parameter", "Group", "Mean_Group1", "Mean_Group2", "Method"))
+  # wilcox test
+  if (insight::model_info(x)$is_ranktest && !insight::model_info(x)$is_correlation) {
+    table_full <- cbind(table_full, attributes(effsize)$table)
+  }
 
   # Return output
   as.report_table(table_full, summary = table, effsize = effsize)
@@ -138,7 +169,6 @@ report_table.htest <- function(x, ...) {
 
 # report_statistics ------------------------------------------------------------
 
-
 #' @rdname report.htest
 #' @export
 report_statistics.htest <- function(x, table = NULL, ...) {
@@ -149,13 +179,17 @@ report_statistics.htest <- function(x, table = NULL, ...) {
   effsize <- attributes(table)$effsize
 
   # Estimate
-  candidates <- c("rho", "r", "tau", "Difference")
+  candidates <- c("rho", "r", "tau", "Difference", "r_rank_biserial")
   estimate <- candidates[candidates %in% names(table)][1]
   text <- paste0(tolower(estimate), " = ", insight::format_value(table[[estimate]]))
 
   # CI
   if (!is.null(attributes(x$conf.int)$conf.level)) {
-    text <- paste0(text, ", ", insight::format_ci(table$CI_low, table$CI_high, ci = attributes(x$conf.int)$conf.level))
+    text <- paste0(
+      text,
+      ", ",
+      insight::format_ci(table$CI_low, table$CI_high, ci = attributes(x$conf.int)$conf.level)
+    )
   }
 
   # Statistic
@@ -171,6 +205,8 @@ report_statistics.htest <- function(x, table = NULL, ...) {
     text <- paste0(text, ", S = ", insight::format_value(table$S))
   } else if ("z" %in% names(table)) {
     text <- paste0(text, ", z = ", insight::format_value(table$z))
+  } else if ("W" %in% names(table)) {
+    text <- paste0("W = ", insight::format_value(table$W))
   } else if ("Chi2" %in% names(table)) {
     text <- paste0(text, ", Chi2 = ", insight::format_value(table$Chi2))
   }
@@ -179,7 +215,8 @@ report_statistics.htest <- function(x, table = NULL, ...) {
   text <- paste0(text, ", ", insight::format_p(table$p, stars = FALSE, digits = "apa"))
 
   # Effect size
-  if (insight::model_info(x)$is_ttest) {
+  if (insight::model_info(x)$is_ttest ||
+    (insight::model_info(x)$is_ranktest && !insight::model_info(x)$is_correlation)) {
     text_full <- paste0(text, "; ", attributes(effsize)$statistics)
     text <- paste0(text, ", ", attributes(effsize)$main)
   } else {
@@ -265,21 +302,14 @@ report_model.htest <- function(x, table = NULL, ...) {
   }
 
   if (insight::model_info(x)$is_correlation) {
-    text <- paste0(
-      x$method,
-      " between ",
-      x$data.name
-    )
-  } else {
+    text <- paste0(x$method, " between ", x$data.name)
+  }
 
+  if (insight::model_info(x)$is_ttest) {
     # If against mu
     if (names(x$null.value) == "mean") {
       table$Difference <- x$estimate - x$null.value
-      means <- paste0(
-        " (mean = ",
-        insight::format_value(x$estimate),
-        ")"
-      )
+      means <- paste0(" (mean = ", insight::format_value(x$estimate), ")")
       vars_full <- paste0(x$data.name, means, " and mu = ", x$null.value)
       vars <- paste0(x$data.name, " and mu = ", x$null.value)
 
@@ -302,6 +332,29 @@ report_model.htest <- function(x, table = NULL, ...) {
     )
   }
 
+  if (insight::model_info(x)$is_ranktest && !insight::model_info(x)$is_correlation) {
+    # two-sample
+    if ("Parameter1" %in% names(table)) {
+      vars_full <- paste0(table$Parameter1[[1]], " and ", table$Parameter2[[1]])
+
+      text <- paste0(
+        trimws(x$method),
+        " testing the difference in ranks between ",
+        vars_full
+      )
+    } else {
+      # one-sample
+      vars_full <- paste0(table$Parameter[[1]])
+
+      text <- paste0(
+        trimws(x$method),
+        " testing the difference in rank for ",
+        vars_full,
+        " and true location of 0"
+      )
+    }
+  }
+
   as.report_model(text, summary = text)
 }
 
